TILE_FIRE=3
TILE_PIKE=9

TILE_RED=25

TILE_START=32

TILE_ENEMY=33
TILE_ENEMY2=34
TILE_ENEMY3=35

TILE_LADDER=2
TILE_PICKAXE=4
TILE_SOLID=15	; Tiles >= this value are considered solid (can be stood uppon)

TILE_GOLD=1
TILE_TELEPORT=11

TILE_MINE=21
TILE_ACTIVEMINE=28

TILE_LEFT=22
TILE_RIGHT=23

TILE_ANTILEFT=26
TILE_ANTIRIGHT=27

TILE_MEGASOLID=24

TILE_BRIDGE1=17
TILE_BRIDGE=18
TILE_BRIDGE2=19


 STRUCT OBJMAP
idStr		ds	7	; Yazzie1
theme		db
musTrack	db
author		ds	3	; Fill with 0 when unused
title		ds	19	; Must be ended with FFh
headerEnd	db	0
layout		ds	32*23	; 32 columns, 23 rows
 ENDS


loadLevelROM:	; Loads a level from the ROM
	; Change the theme according to the stage
	ld	a,(currentLevel)
	cp	11
	jr	nc,20f
	call	fillTiles01
	jr	50F
20:	cp	21
	jr	nc,30f
	call	fillTiles02
	jr	50F
30:	call	fillTiles03
50:

    ld a,(currentLevel)
	dec	a
   	ld hl,levels :  add a,a : ld c,a : ld b,0 : add hl,bc
	ld a,(hl): inc hl : ld h,(hl) : ld l,a

	ld	iy,enemiesList		;pointer to start of enemies list
	ld	(curShowEnemy),iy
	;unpack level
	ld	de,map :	call	DEC40
.clrLin25:	; Make sure the additional line is cleared
	ld	hl,map+32*24
	ld	bc,32*256
10:	ld	(hl),c
	inc	hl
	djnz	10B
	ret

loadLevelFile:	; Loads a level from a file
		; Output: Cy set = Read error
	ld	iy,enemiesList		;pointer to start of enemies list
	ld	(curShowEnemy),iy
	ld	hl,filename
	ld	de,map
	ld	bc,32*24
	call	EZFILELIB.RAWRAMLOAD
	call	stopDrive
	jr	nz,.fileNotFound
	jr	c,.fileReadError
	; Check the file header
	ld	hl,map
	ld	de,.yazzieHeaderStr
	ld	bc,7
100:	ld	a,(de)
	cpi
	jr	nz,.incorrectFileError
	inc	de
	jp	pe,100B
	call	loadLevelROM.clrLin25
	call	startPlayer
	; Change the theme according to the stage
	ld	a,(map+OBJMAP.theme)	; Get the theme number
	or	a
	jr	nz,10F
	call	xrnd16
	ld	a,h
	add	l
	ld	e,a
	ld	c,86
	call	Div8
	inc	a
10:	cp	1
	jr	nz,20F
	call	fillTiles01
	xor	a		; Clear Cy
	ret
20:	cp	2
	jr	nz,30F
	call	fillTiles02
	xor	a		; Clear Cy
	ret
30:	call	fillTiles03
	xor	a		; Clear Cy
	ret

.yazzieHeaderStr:
	db	"Yazzie1"

.incorrectFileError:
	ld	bc,errorMsg.incorrectFile
	jp	showError

.fileNotFound:
	ld	bc,errorMsg.fileNotFound
	jp	showError
.fileReadError:
	ld	bc,errorMsg.fileReadError
	jp	showError

initLevel:		
	ld	a,75 :	ld (deadCount),a
	call	resetHero
	call	resetEnemies
	call	resetMines
	xor	a :	ld (totalGold),a

	; Unpack showFX random data
	ld	de,fxData		; Randomly ordered indexes
	ld	(curShowFX),de
	jp	genRndTransitionTable

showLevel:
    ;skip top row
	ld	hl,(curShowFX)
	ld	e,(hl)			; get xPos
	inc	hl
	ld	d,(hl)			; get yPos
	ld	a,d
	inc	hl
	ld	(curShowFX),hl
	inc	a			; a=#FF?
	jr	nz,.doTile
	ld	hl,musicBuffer
	ld	(curShowFX),hl
.end:	ld	a,GS_GAMEPLAY
	ld	(gameState),a
	ld	a,GSS_GAMEPLAY_INTERACT
	ld	(gameState),a
	; Update the status bar
	call doHero : call doEnemies : call doSprites
	call drawLevel: call drawLive : call drawGold : call drawPickaxe
	jp	initLevelMusic


.doTile:	; Process a single tile 
	call	tileCoordsToMapAddr
	ld	a,(hl)

	cp	TILE_START
	call	z,setStartPoint

	cp	TILE_ENEMY
	call	z,addEnemy

	cp	TILE_GOLD
	jr	nz,50f
	ld	c,a	: ld a,(totalGold) : inc a : ld (totalGold),a : ld a,c
50:
	jp	fillTile

showLevelQuick:
	ld	hl,#1800+32
	call	SETWRT
	ld	bc,(VDP.DW)
	ld	hl,map+32
	ld	d,1		; map y=1
70:	ld	b,32		; 32 columns
80:	ld	a,(hl)

	cp	TILE_GOLD
	jr	nz,90F
	ex	af,af'	: ld a,(totalGold) : inc a : ld (totalGold),a : ex af,af': jr 105F

90:	cp	TILE_ENEMY
	jr	nz,100F
	ld	a,32
	sub	b
	ld	e,a
	push	bc
	call	addEnemy
	pop	bc
	jr	105F

100:	cp	TILE_START
	jr	nz,105F
	ld	a,32
	sub	b
	ld	e,a
	call	setStartPoint

105:	out	(c),a
	inc	hl
	
110:	djnz	80B
	ld	e,0
	inc	d
	ld	a,d
	cp	24
	jr	c,70B
	jp	showLevel.end

addEnemy:
	ld	iy,(curShowEnemy)
	;get real coords and put it to enemy coords
	ld a,e : add a,a : add a,a : add a,a : ld (iy+OBJENEMY.xPos),a : ld (iy+OBJENEMY.startX),a
	ld a,d : add a,a : add a,a : add a,a  : sub 2 : ld (iy+OBJENEMY.startY),a : ld (iy+OBJENEMY.yPos),a	

	;move to next enemy
	ld bc, OBJENEMY : add iy,bc
	ld	(curShowEnemy),iy
	xor a		;reset tile
	ld (hl),a 	;tile
	ret

setStartPoint:
    ld a,e : add a,a : add a,a : add a,a : ld (hero.xPos),a
    ld a,d: add a,a : add a,a : add a,a : sub 4 : ld (hero.yPos),a
    xor a; reset tile
    ld (hl),a
    ret


tileCoordsToMapAddr:				; Use Map coords directly
	ld	a,d
	jr	getTileCoords.part2

;de - real coords
;out: de-tile coords
;     hl - map coords
getTileCoords:
;fix x
	ld a,e : add 4
	rra : rra : rra ;/8
	and 31
	ld e,a	

	;get y
	ld a,d : add 6
	rra : rra : rra ;/8
	and 31
	ld d,a

.part2:	push de

	ld h, high mapLines
	add a,a;x2 2bytes per addr
	ld l,a
	ld a,(hl): inc l : ld h,(hl) : ld l,a
	
	ld d,0 : add hl,de

	pop de
	ret


;de - coords
getTile:	
	;fix x
	ld a,e : add 4
	rra : rra : rra ;/8
	and 31
	ld e,a	

	;get y
	ld a,d : add 6
	rra : rra : rra ;/8
	and 31
	ld h, high mapLines
	add a,a;x2 2bytes per addr
	ld l,a
	ld a,(hl): inc l : ld h,(hl) : ld l,a
	
	ld d,0 : add hl,de
	ld a,(hl)
	ret

