
doMenu:
	ld	hl,0
	ld	(timer),hl
10:
	halt
	ld	a,(timer)
	and	#10
	call	drawPushFire

	ld	a,(joyPressed)
 	and	#10
	jr	z,30F		; Start game if button-1 was pushed

	ld	a,(HPHYD)
	cp	#C9		; Is there a disk interface present?
	ld	a,(kbdRow4Status)
	jr	z,15F
	bit	1,a		; L pressed?
	jr	z,menuCustomStage
15:	and	#C0		; Q+R pressed?
	jr	z,20F

	ld	hl,(timer)
	ld	de,MENUWAIT	; Music looped 3 times?
	rst	DCOMPR
	jr	c,10B		; No keep waiting
20:	; Start a demoplay
	call	muteMusic
	ld	a,GS_STARTLEVEL
	ld	(gameState),a
	ld	a,GSS_GAMEPLAY_DEMOPLAY
	ld	(gameSubState),a
	xor	a		; Clear Cy
	ret

	
30:	; Start the game
	ld	a,(timer)		; Force drawPushFire to flip
	cpl
	and	#10
	call	drawPushFire
	call	muteMusic
	ld	a,13 : call AFXPLAY3	

	ld	b,100
50:
	halt
	push	bc
	ld	a,(timer)
	and	4
	call	drawPushFire
	pop	bc
	djnz	50b

	ld	a,GS_STARTLEVEL
	ld	(gameState),a
	ld	a,GSS_GAMEPLAY_INTERACT
	ld	(gameSubState),a
	xor	a			; Clear Cy
	ret


menuCustomStage:
	call	muteMusic
	call	stopPlayer
.newDisk:
	call	clearScreen
	call	fillFont
	call	chkDiskChange

	ld	hl,FCBPNT
	call	EZFILELIB.INIFCB
	ld	de,FCBPNT+DOSFCB.filename
	ld	hl,.wildcard
	ld	bc,11
	ldir
	ld	de,fileBuf
	ld	c,_SETDTA
	call	EZFILELIB.BDOS

	ld	de,FCBPNT
	ld	c,_SFIRST
	call	EZFILELIB.BDOS
	jp	c,.diskError
	or	a
	jp	nz,.fileNotFound
	jr	10F
.listFiles:
	call	clearScreen
10:	ld	hl,#1800
	call	SETWRT
	ld	de,#4503		; 69 files/page, 3 files/column
.whileListFiles:
	ld	hl,fileBuf+DOSFCB.filename
	call	.printfnam
	push	de
	ld	c,_SNEXT
	call	EZFILELIB.BDOS
	jp	c,.diskError
	pop	de
	dec	d
	jr	z,.nextPage
	or	a
	jr	z,.whileListFiles

	ld	de,FCBPNT
	ld	c,_SFIRST
	call	EZFILELIB.BDOS
	jr	c,.diskError
	or	a
	jp	nz,.fileNotFound

.nextPage:
	call	stopDrive
	ld	bc,nextPageText
	call	drawString

	ld	hl,#1801
.selectFile:
	halt			; Wait for a keyboard update
	ld	a,">"+256-96-32
	call	WRTVRM
10:	; While
	ld	a,(fnBtnPressed)
	bit	5,a		; ESC pressed?
	scf
	jp	z,startPlayer	; Yes, abort
	bit	6,a		; TAB pressed?
	jp	z,.newDisk
	ld	a,(joyPressed)
	bit	5,a		; Button-2 pressed?
	jr	z,.listFiles
	bit	4,a		; Button-1 pressed?
	jr	z,.chkSelection
	bit	0,a		; Up pressed?
	ld	bc,32
	jr	nz,20F
	jr	150F
20:	bit	1,a		; Down Pressed?
	jr	nz,30F
	jr	100F
30:	bit	2,a		; Left Pressed?
	ld	bc,11
	jr	nz,40F
	jr	150F
40:	bit	3,a		; Right Pressed?
	jr	nz,.selectFile
	;
100:	ld	a," "+256-96-32
	call	WRTVRM
	add	hl,bc
	; Check for X overflow
	ld	a,l
	and	31
	cp	2
	jr	nz,110F
	or	a
	sbc	hl,bc
110:	; Check for Y overflow
	ld	de,#1800+23*32
	rst	DCOMPR
	jr	c,.selectFile
	sbc	hl,bc
	jr	.selectFile

150:	ld	a," "+256-96-32
	call	WRTVRM
	or	a
	sbc	hl,bc
	; Check for X overflow
	ld	a,l
	and	31
	cp	22
	jr	nz,160F
	add	hl,bc
160:	; Check for Y overflow
	ld	de,#1800
	rst	DCOMPR
	jr	nc,.selectFile
	add	hl,bc
	jr	.selectFile

.diskError:
	ld	bc,errorMsg.diskError
	jp	showError
.fileNotFound:
	ld	bc,errorMsg.fileNotFound
	jp	showError

.chkSelection:
	; Get the filename from the VRAM
	inc	hl
	call	RDVRM
	or	a		; Empty entry?
	jr	nz,190F		; No, skip
	; Empty entry: try again
	dec	hl
	jp	.selectFile
190:	call	SETRD
	ld	de,filename
	ld	bc,(VDP.DR)
	ld	b,8
200:	in	a,(c)
	sub	256-96-32
	ld	(de),a
	inc	de
	djnz	200B
	; Copy the extension
	ld	hl,.wildcard+8
	ld	bc,3
	ldir
300:	ld	a,GS_STARTLEVEL
	ld	(gameState),a
	ld	a,GSS_GAMEPLAY_USRLEVEL
	ld	(gameSubState),a
	xor	a		; Clear Cy
	ret

.printfnam:
	ld	bc,(VDP.DW)

	ld	a," "+256-96-32
	out	(c),a
	push	af
	pop	af
	out	(c),a

	ld	b,8
500:	ld	a,(hl)
	inc	hl
	add	256-96-32
	out	(c),a
	djnz	500B

	dec	e
	jr	z,510F
	ld	a," "+256-96-32
	out	(c),a
	ret
510:	ld	e,3
	ret


.wildcard:
	db	"????????YAZ"



